Module: Snooby::Delete
Instance Method Summary collapse
-
#delete ⇒ Object
Deletes the calling object, which is either a post or a comment.
Instance Method Details
#delete ⇒ Object
Deletes the calling object, which is either a post or a comment.
40 41 42 |
# File 'lib/snooby/actions.rb', line 40 def delete Snooby.request Paths[:delete], :id => self.name end |