Exception: Snooby::RedditError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/snoobyplus.rb

Overview

Raised with a pretty print of the relevant JSON object whenever an API call returns a non-empty “errors” array, typically in cases of rate limiting and missing or insufficient authorization. Also used as a general container for miscellaneous errors related to site functionality.