Module: Snooby::Reply
Instance Method Summary collapse
-
#reply(text) ⇒ Object
Posts a reply to the calling object, which is either a post or a comment.
Instance Method Details
#reply(text) ⇒ Object
Posts a reply to the calling object, which is either a post or a comment.
33 34 35 |
# File 'lib/snooby/actions.rb', line 33 def reply(text) Snooby.request Paths[:comment], :parent => self.name, :text => text end |